# Aufmerksamkeit bitte!

Dieses Experiment wurde mit einer älteren Version von OpenSesame erstellt. 

Keine Sorge! Das sollte keine Probleme verursachen. Um ganz auf Nummer sicher zu gehen, empfehle ich Dir aber Dein Experiment unter einem neuen Namen zu speichern.

Was möchtest Du tun?

[Experiment jetzt speichern](opensesame://action.save){: .important-button} <br />
[Anschauen was es Neues gibt bei OpenSesame 3](new:html://osdoc.cogsci.nl/3.0/miscellaneous/important-changes-3/){: .button} <br />

Oder:

[Diese Nachricht dauerhaft ausblenden](opensesame://event.os3n_dismiss_old_experiment){: .dismiss-button}
